@@ -3,7 +3,7 @@ BEGIN {
   $App::Installer::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::Installer::VERSION = '0.005';
+  $App::Installer::VERSION = '0.006';
 }
 # ABSTRACT: Application class for Installer
 
@@ -33,12 +33,6 @@ has 'url' => (
   predicate => 1,
 );
 
-has file_path => (
-  is => 'ro',
-  lazy => 1,
-  default => sub { file($_[0]->file)->absolute->stringify },
-);
-
 sub install_to_target {
   my ( $self ) = @_;
   my $target = $self->target;
@@ -49,7 +43,7 @@ sub install_to_target {
   } elsif ($self->has_url) {
     $installer_code = io($self->url)->get->content;
   } else {
-    $installer_code = io($self->file_path)->all;
+    $installer_code = io($self->file)->all;
   }
   my $target_class = 'App::Installer::Sandbox'.$$;
 
@@ -86,7 +80,7 @@ App::Installer - Application class for Installer
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
